@@ -1,5 +1,5 @@
 package App::ansifold;
-our $VERSION = "1.25";
+our $VERSION = "1.26";
 
 use v5.14;
 use warnings;
@@ -96,7 +96,8 @@ use Getopt::EX::Hashed 'has'; {
 	$_->runin = $_->runout = $_[1];
     };
     # for backward compatibility, would be deplicated
-    has 'run' => sub {
+    has run => '=i';
+    has '+run' => sub {
 	$_->runin = $_->runout = $_[1];
     };
 
@@ -139,7 +140,6 @@ sub options {
 
     ## --colrm
     if ($app->colrm) {
-	$app->separate = '';
 	my @params;
 	while (@ARGV > 0 and $ARGV[0] =~ /^\d+$/) {
 	    push @params, shift @ARGV;
@@ -148,7 +148,6 @@ sub options {
     }
     ## --cut
     elsif ($app->cut) {
-	$app->separate = '';
 	@{$app->width} = cut_to_width($app->cut);
     }
 
